@@ -9,12 +9,15 @@ from dynamic_preferences.forms import preference_form_builder
 
 from ephios.core.forms.events import EventTypeForm, EventTypePreferenceForm
 from ephios.core.models import EventType
-from ephios.extra.permissions import CustomPermissionRequiredMixin
+from ephios.core.views.settings import SettingsViewMixin
+from ephios.extra.mixins import CustomPermissionRequiredMixin
 
 
-class EventTypeUpdateView(CustomPermissionRequiredMixin, TemplateView, SingleObjectMixin):
+class EventTypeUpdateView(
+    CustomPermissionRequiredMixin, SettingsViewMixin, TemplateView, SingleObjectMixin
+):
     template_name = "core/eventtype_form.html"
-    permission_required = "core.add_event"
+    permission_required = "core.change_eventtype"
     model = EventType
 
     def dispatch(self, request, *args, **kwargs):
@@ -47,13 +50,14 @@ class EventTypeUpdateView(CustomPermissionRequiredMixin, TemplateView, SingleObj
         )
 
 
-class EventTypeListView(CustomPermissionRequiredMixin, ListView):
-    permission_required = "core.add_event"
+class EventTypeListView(CustomPermissionRequiredMixin, SettingsViewMixin, ListView):
+    permission_required = "core.view_eventtype"
+    accept_object_perms = False
     model = EventType
 
 
-class EventTypeDeleteView(CustomPermissionRequiredMixin, DeleteView):
-    permission_required = "core.add_event"
+class EventTypeDeleteView(CustomPermissionRequiredMixin, SettingsViewMixin, DeleteView):
+    permission_required = "core.delete_eventtype"
     model = EventType
 
     def get_success_url(self):
@@ -63,8 +67,11 @@ class EventTypeDeleteView(CustomPermissionRequiredMixin, DeleteView):
         return reverse("core:settings_eventtype_list")
 
 
-class EventTypeCreateView(CustomPermissionRequiredMixin, SuccessMessageMixin, CreateView):
-    permission_required = "core.add_event"
+class EventTypeCreateView(
+    CustomPermissionRequiredMixin, SettingsViewMixin, SuccessMessageMixin, CreateView
+):
+    permission_required = "core.add_eventtype"
+    accept_object_perms = False
     template_name = "core/eventtype_form.html"
     model = EventType
     fields = ["title", "can_grant_qualification"]
@@ -73,4 +80,4 @@ class EventTypeCreateView(CustomPermissionRequiredMixin, SuccessMessageMixin, Cr
     )
 
     def get_success_url(self):
-        return reverse("core:setting_eventtype_edit", kwargs=dict(pk=self.object.pk))
+        return reverse("core:settings_eventtype_edit", kwargs=dict(pk=self.object.pk))
