@@ -134,6 +134,7 @@ class SectionBasedConfigurationForm(forms.Form):
                 for key in ("title", "qualifications", "min_count", "uuid")
             }
             for form in self.sections_formset
+            if not form.cleaned_data.get("DELETE")
         ]
         return sections
 
@@ -274,7 +275,9 @@ class SectionBasedSignupMethod(BaseSignupMethod):
                 "relevant_qualifications": ", ".join(
                     participation.participant.qualifications.filter(
                         category__in=relevant_qualification_categories
-                    ).values_list("abbreviation", flat=True)
+                    )
+                    .order_by("category", "abbreviation")
+                    .values_list("abbreviation", flat=True)
                 ),
                 "uuid": dispatched_section_uuid,
             }
