@@ -1,7 +1,11 @@
 import copy
 import os
 from email.utils import getaddresses
-from importlib import metadata
+
+try:
+    import importlib_metadata  # importlib is broken on python3.8, using backport
+except ImportError:
+    import importlib.metadata as importlib_metadata
 
 import environ
 from cryptography.hazmat.primitives import serialization
@@ -55,6 +59,7 @@ INSTALLED_APPS = [
     "dynamic_preferences.users.apps.UserPreferencesConfig",
     "crispy_forms",
     "webpush",
+    "ephios.modellogging",
 ]
 
 EPHIOS_CORE_MODULES = [
@@ -67,9 +72,10 @@ CORE_PLUGINS = [
     "ephios.plugins.basesignup",
     "ephios.plugins.pages",
     "ephios.plugins.guests",
+    "ephios.plugins.eventautoqualification",
 ]
 PLUGINS = copy.copy(CORE_PLUGINS)
-for ep in metadata.entry_points().get("ephios.plugins", []):
+for ep in importlib_metadata.entry_points().get("ephios.plugins", []):
     PLUGINS.append(ep.module)
 
 INSTALLED_APPS += PLUGINS
@@ -85,6 +91,7 @@ MIDDLEWARE = [
     "django.contrib.messages.middleware.MessageMiddleware",
     "django.middleware.clickjacking.XFrameOptionsMiddleware",
     "csp.middleware.CSPMiddleware",
+    "ephios.modellogging.middleware.LoggingRequestMiddleware",
 ]
 
 ROOT_URLCONF = "ephios.urls"
@@ -131,7 +138,7 @@ AUTH_PASSWORD_VALIDATORS = [
         "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator",
     },
     {
-        "NAME": "ephios.core.utils.CustomMinimumLengthValidator",
+        "NAME": "ephios.core.services.password_reset.CustomMinimumLengthValidator",
     },
     {
         "NAME": "django.contrib.auth.password_validation.CommonPasswordValidator",
@@ -183,6 +190,28 @@ DEFAULT_FROM_EMAIL = env.str("DEFAULT_FROM_EMAIL")
 SERVER_EMAIL = env.str("SERVER_EMAIL")
 ADMINS = getaddresses([env("ADMINS")])
 
+# logging
+if not DEBUG:
+    LOGGING = {
+        "version": 1,
+        "disable_existing_loggers": True,
+        "handlers": {
+            "mail_admins": {"level": "ERROR", "class": "django.utils.log.AdminEmailHandler"}
+        },
+        "loggers": {
+            "django": {
+                "handlers": ["mail_admins"],
+                "level": "ERROR",
+                "propagate": False,
+            },
+        },
+        "root": {
+            "handlers": ["mail_admins"],
+            "level": "ERROR",
+        },
+    }
+
+
 # Guardian configuration
 ANONYMOUS_USER_NAME = None
 GUARDIAN_MONKEY_PATCH = False
@@ -205,9 +234,12 @@ if DEBUG:
 # bootstrap v5 or v6. See https://github.com/twbs/bootstrap/issues/25394 for details on the problem and
 # https://security.stackexchange.com/a/167244 on why allowing data: is considered okay
 CSP_IMG_SRC = ("'self'", "data:")
+CSP_STYLE_SRC = ("'self'",)
+CSP_INCLUDE_NONCE_IN = ["style-src"]
 
 # django-crispy-forms
 CRISPY_TEMPLATE_PACK = "bootstrap4"
+CRISPY_FAIL_SILENTLY = not DEBUG
 
 # django.contrib.messages
 MESSAGE_TAGS = {
